function H = fr3bandmeyer(omega,ep)

%function H = fr3bandmeyer(omega,ep)
%
%Generation of Meyer 3 band filters (frequential)
%INPUT:
%   omega: pulsations
%   ep: epsilon
%OUTPUT:
%   H: frequential response

%*****************************************************
%* author: Caroline Chaux                            *
%* institution: Institut Gaspard Monge - CNRS	     *
%*	       Universit de Marne la Valle             *
%* date: Thursday, November, 2nd 2006                *
%* License CeCILL-B				      *
%*****************************************************


if ep <0 | ep > 1/4
    error('epsilon should be chosen between 0 and 1/4')
end

H = zeros(3,length(omega));

omega = angle(exp(i*omega));

aomega = abs(omega);

ind = find(aomega<=pi*(1-ep)/3);
H(1,ind) = sqrt(3);
ind = find(aomega>pi*(1-ep)/3 & aomega<pi*(1+ep)/3 );
H(1,ind) = rhomeyer(aomega(ind)-pi*(1-ep)/3,ep,3);

ind = find(aomega>pi*(1-ep)/3 & aomega<pi*(1+ep)/3);
H(2,ind) = rhomeyer(aomega(ind)-pi*(1+ep)/3,ep,3);
ind = find(aomega>=pi*(1+ep)/3 & aomega<=pi*(2-ep)/3);
H(2,ind) = sqrt(3);
ind = find(aomega>pi*(2-ep)/3 & aomega<pi*(2+ep)/3);
H(2,ind) = rhomeyer(aomega(ind)-pi*(2-ep)/3,ep,3);

ind = find(aomega>pi*(2-ep)/3 & aomega<pi*(2+ep)/3);
H(3,ind) = rhomeyer(aomega(ind)-pi*(2+ep)/3,ep,3);
ind = find(aomega>=pi*(2+ep)/3);
H(3,ind) = sqrt(3);


H(2,:) = H(2,:).*exp(-3/2*i*omega);

% ind = find(omega~=pi);
% H(3,ind) = H(3,ind).*exp(-3/4*i*omega(ind));

ind = find(omega>=-pi*(2+ep)/3 & omega<=pi*(2+ep)/3);
H(3,ind) = H(3,ind).*exp(-3/4*i*omega(ind));

ind = find(omega>pi*(2+ep)/3);
phi=3/4*(2+ep)/(1-ep)*(omega(ind)-pi);
H(3,ind) = H(3,ind).*exp(i*phi);

ind = find(omega<-pi*(2+ep)/3);
phi=3/4*(2+ep)/(1-ep)*(omega(ind)+pi);
H(3,ind) = H(3,ind).*exp(i*phi);


